'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

/**
 * @async
 * @function sendContractTransaction
 *
 * @description Sends contract transaction
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {string} payload.props.privateKey - Private key (64 hex symbols, without '0x' prefix)
 * @param {object} payload.contractInstance - Contract instance
 * @param {string} payload.interfaceName - Interface name
 * @param {string} payload.method - Method name
 * @param {array} payload.args - Method arguments
 *
 * @returns Promise that will be resolved with the hash of the contract transaction
 */
var sendContractTransaction = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(payload) {
    var contractInstance, interfaceName, method, props, args, privateKey, contractMethod, address, transactionObject, rawTx, signedTx;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            contractInstance = payload.contractInstance, interfaceName = payload.interfaceName, method = payload.method, props = payload.props, args = payload.args;
            privateKey = props.privateKey;
            contractMethod = contractInstance[method];
            address = (0, _getAddressFromPrivateKey2.default)(privateKey);

            // Extend contract method args. Add transaction object as last argument

            transactionObject = { from: address };

            args.push(transactionObject);

            _context.next = 8;
            return (0, _txUtils.getContractRawTx)({ props: props, address: address, contractMethod: contractMethod, args: args });

          case 8:
            rawTx = _context.sent;
            signedTx = (0, _txUtils.signTx)(rawTx, privateKey);
            return _context.abrupt('return', _bluebird2.default.promisify(jWeb3.eth.sendRawTransaction)(signedTx).timeout(_config2.default.promiseTimeout, new Error('Can not submit ' + interfaceName + '.' + method + ' within ' + _config2.default.promiseTimeout + 'ms')));

          case 11:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function sendContractTransaction(_x) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * @function subscribeToContractEvent
 *
 * @description Subscribes to specific contract event
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {object} [payload.props.options] - Event options (@see subscribe)
 * @param {eventCallback} [payload.props.callback] - Event callback (@see subscribe)
 * @param {object} payload.contractInstance - Contract instance
 * @param {string} payload.method - Event name
 *
 * @returns {object} The event emitter (@see subscribe)
 */


var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _getContractInstance = require('./getContractInstance');

var _getContractInstance2 = _interopRequireDefault(_getContractInstance);

var _getAddressFromPrivateKey = require('../getAddressFromPrivateKey');

var _getAddressFromPrivateKey2 = _interopRequireDefault(_getAddressFromPrivateKey);

var _validation = require('../../validation');

var _validation2 = _interopRequireDefault(_validation);

var _checkWeb = require('../../utils/checkWeb3');

var _checkWeb2 = _interopRequireDefault(_checkWeb);

var _eventUtils = require('../../utils/eventUtils');

var _txUtils = require('../../utils/txUtils');

var _config = require('../../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @async
 * @function call
 *
 * @description Wrapper for callContractMethod function (@see callContractMethod)
 */
/**
 * @file Manages web3.eth.contract wrapper
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function call(payload) {
  return prepareContractInstanceMethod(payload).then(callContractMethod);
}

/**
 * @async
 * @function sendTransaction
 *
 * @description Wrapper for sendContractTransaction function (@see sendContractTransaction)
 */
function sendTransaction(payload) {
  return prepareContractInstanceMethod(payload).then(sendContractTransaction);
}

/**
 * @async
 * @function subscribeToEvent
 *
 * @description Wrapper for subscribeToContractEvent function (@see subscribeToContractEvent)
 */
function subscribeToEvent(payload) {
  return prepareContractInstanceMethod(payload).then(subscribeToContractEvent);
}

/**
 * @async
 * @function getPastEvents
 *
 * @description Wrapper for getPastContractEvents function (@see getPastContractEvents)
 */
function getPastEvents(payload) {
  return prepareContractInstanceMethod(payload).then(getPastContractEvents);
}

/**
 * @async
 * @function estimateGas
 *
 * @description Wrapper for estimateContractGas function (@see estimateContractGas)
 */
function estimateGas(payload) {
  return prepareContractInstanceMethod(payload).then(estimateContractGas);
}

function prepareContractInstanceMethod(payload) {
  return _bluebird2.default.bind(this, payload).then(_validation2.default).then(_checkWeb2.default).then(_getContractInstance2.default);
}

/**
 * @async
 * @function callContractMethod
 *
 * @description Calls specific contract method with provided arguments
 *
 * @param {object} payload - Payload object
 * @param {object} payload.contractInstance - Contract instance
 * @param {string} payload.interfaceName - Interface name
 * @param {string} payload.method - Method name
 * @param {array} payload.args - Method arguments
 *
 * @returns Promise that will be resolved with the result of contract method execution
 */
function callContractMethod(payload) {
  var contractInstance = payload.contractInstance,
      interfaceName = payload.interfaceName,
      method = payload.method,
      args = payload.args;


  return _bluebird2.default.promisify(contractInstance[method].call).apply(undefined, (0, _toConsumableArray3.default)(args)).timeout(_config2.default.promiseTimeout, new Error('Can not call ' + interfaceName + '.' + method + ' within ' + _config2.default.promiseTimeout + 'ms'));
}function subscribeToContractEvent(payload) {
  var props = payload.props,
      contractInstance = payload.contractInstance,
      method = payload.method;
  var options = props.options,
      callback = props.callback;


  return (0, _eventUtils.subscribe)(contractInstance[method], options, callback);
}

/**
 * @async
 * @function getPastContractEvents
 *
 * @description Gets past contract events
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {string} payload.props.event - Event name
 * @param {object} [payload.props.options] - Event options (@see getEvents)
 * @param {object} payload.contractInstance - Contract instance
 *
 * @returns Promise that will be resolved with past events (@see getEvents)
 */
function getPastContractEvents(payload) {
  var props = payload.props,
      contractInstance = payload.contractInstance;
  var event = props.event,
      options = props.options;


  return (0, _eventUtils.getEvents)(contractInstance[event], options);
}

/**
 * @async
 * @function estimateContractGas
 *
 * @description Gets estimate gas for the contract transaction
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {string} payload.props.method - Contract method name
 * @param {array} payload.props.args - Contract method arguments
 * @param {string} payload.props.privateKey - Private key (64 hex symbols, without '0x' prefix)
 * @param {object} payload.contractInstance - Contract instance
 *
 * @returns Promise (@see getContractGasLimit)
 */
function estimateContractGas(payload) {
  var contractInstance = payload.contractInstance,
      props = payload.props;
  var method = props.method,
      args = props.args,
      privateKey = props.privateKey;


  var address = (0, _getAddressFromPrivateKey2.default)(privateKey);

  // Extend contract method args. Add transaction object as last argument
  var transactionObject = { from: address };
  args.push(transactionObject);

  return (0, _txUtils.getContractGasLimit)(contractInstance[method], args);
}

exports.default = { call: call, sendTransaction: sendTransaction, subscribeToEvent: subscribeToEvent, getPastEvents: getPastEvents, estimateGas: estimateGas };