'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.name = name;
exports.symbol = symbol;
exports.decimals = decimals;

var _contractMethod = require('./contractMethod');

var _contractMethod2 = _interopRequireDefault(_contractMethod);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var interfaceName = 'ERC20Named';

/**
 * @async
 * @function name
 *
 * @description Gets token name
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the token name
 */
/**
 * @file Exposes ERC20Named API
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function name(props) {
  return _contractMethod2.default.call({ props: props, interfaceName: interfaceName, method: 'name', args: [] });
}

/**
 * @async
 * @function symbol
 *
 * @description Gets token symbol
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the token symbol
 */
function symbol(props) {
  return _contractMethod2.default.call({ props: props, interfaceName: interfaceName, method: 'symbol', args: [] });
}

/**
 * @async
 * @function decimals
 *
 * @description Gets token decimals
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with token decimals
 */
function decimals(props) {
  return _contractMethod2.default.call({ props: props, interfaceName: interfaceName, method: 'decimals', args: [] });
}

exports.default = { name: name, symbol: symbol, decimals: decimals };