'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getAddressFromPrivateKey;

var _cryptoJs = require('crypto-js');

var _cryptoJs2 = _interopRequireDefault(_cryptoJs);

var _elliptic = require('elliptic');

var _add0x = require('../utils/add0x');

var _add0x2 = _interopRequireDefault(_add0x);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ec = new _elliptic.ec('secp256k1');

/**
 * @function getAddressFromPrivateKey
 *
 * @description Gets account's address from its private key
 *
 * @param {string} privateKey - Private key (64 hex symbols, without '0x' prefix)
 *
 * @returns {string} Account's address
 */
/**
 * @file Manages helper function for deriving of address from private key
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function getAddressFromPrivateKey(privateKey) {
  checkPrivateKey(privateKey);

  var keyPair = ec.genKeyPair();
  keyPair._importPrivate(privateKey, 'hex');

  var compact = false;

  var pubKey = keyPair.getPublic(compact, 'hex').slice(2);
  var pubKeyWordArray = _cryptoJs2.default.enc.Hex.parse(pubKey);
  var hash = _cryptoJs2.default.SHA3(pubKeyWordArray, { outputLength: 256 });
  var address = hash.toString(_cryptoJs2.default.enc.Hex).slice(24);

  return (0, _add0x2.default)(address);
}

function checkPrivateKey(privateKey) {
  var isTypeValid = typeof privateKey === 'string';
  var isLengthValid = privateKey.length === 64;
  var isContentValid = /^[a-fA-F0-9]+/.test(privateKey);

  if (!(isTypeValid && isLengthValid && isContentValid)) {
    throw new Error('Private key \'' + privateKey + '\' is invalid');
  }
}