'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getContractRawTx = exports.getRawTx = undefined;

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

/**
 * @async
 * @function getRawTx
 *
 * @description Gets raw transaction data
 *
 * @param {object} props - Properties
 * @param {string} props.address - Address of the transaction sender
 * @param {string} props.to - Address of the transaction receiver
 * @param {BigNumber} props.value - Transaction value
 * @param {BigNumber} [props.gasLimit] - Gas limit for the transaction
 * @param {BigNumber} [props.gasPrice] - Gas price for the transaction
 * @param {number} [props.nonce] - Nonce for the transaction
 * @param {string} [props.data] - Transaction data
 *
 * @returns Promise that will be resolved with raw transaction data
 */
var getRawTx = exports.getRawTx = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(props) {
    var address, to, gasLimit, gasPrice, nonce, data, value, _ref2, _ref3, txNonce, txGasPrice, txGasLimit;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            address = props.address, to = props.to, gasLimit = props.gasLimit, gasPrice = props.gasPrice, nonce = props.nonce, data = props.data;
            value = jWeb3.toHex(props.value);
            _context.next = 4;
            return _bluebird2.default.all([nonce || getNonce(address), gasPrice || getGasPrice(), gasLimit || getGasLimit({ data: data, to: to, value: value })]);

          case 4:
            _ref2 = _context.sent;
            _ref3 = (0, _slicedToArray3.default)(_ref2, 3);
            txNonce = _ref3[0];
            txGasPrice = _ref3[1];
            txGasLimit = _ref3[2];
            return _context.abrupt('return', {
              to: to,
              data: data,
              value: value,
              nonce: jWeb3.toHex(txNonce),
              gasPrice: jWeb3.toHex(txGasPrice),
              gasLimit: jWeb3.toHex(txGasLimit)
            });

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function getRawTx(_x) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * @async
 * @function getContractRawTx
 *
 * @description Gets raw contract transaction data
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {string} payload.props.contractAddress - Contract address
 * @param {BigNumber} [payload.props.gasLimit] - Gas limit for the contract transaction
 * @param {BigNumber} [payload.props.gasPrice] - Gas price for the transaction
 * @param {number} [payload.props.nonce] - Nonce for the transaction
 * @param {string} payload.address - Address of the transaction sender
 * @param {function} payload.contractMethod - Contract method that used to send transaction
 * @param {array} payload.args - Contract method arguments
 *
 * @returns Promise that will be resolved with raw contract transaction data
 */


var getContractRawTx = exports.getContractRawTx = function () {
  var _ref4 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(payload) {
    var props, address, contractMethod, args, contractAddress, gasLimit, gasPrice, nonce, _ref5, _ref6, txData, txNonce, txGasPrice, txGasLimit;

    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            props = payload.props, address = payload.address, contractMethod = payload.contractMethod, args = payload.args;
            contractAddress = props.contractAddress, gasLimit = props.gasLimit, gasPrice = props.gasPrice, nonce = props.nonce;
            _context2.next = 4;
            return _bluebird2.default.all([contractMethod.getData.apply(contractMethod, (0, _toConsumableArray3.default)(args)), nonce || getNonce(address), gasPrice || getGasPrice(), gasLimit || getContractGasLimit(contractMethod, args)]);

          case 4:
            _ref5 = _context2.sent;
            _ref6 = (0, _slicedToArray3.default)(_ref5, 4);
            txData = _ref6[0];
            txNonce = _ref6[1];
            txGasPrice = _ref6[2];
            txGasLimit = _ref6[3];
            return _context2.abrupt('return', {
              data: txData,
              to: contractAddress,
              nonce: jWeb3.toHex(txNonce),
              gasPrice: jWeb3.toHex(txGasPrice),
              gasLimit: jWeb3.toHex(txGasLimit)
            });

          case 11:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function getContractRawTx(_x2) {
    return _ref4.apply(this, arguments);
  };
}();

/**
 * @async
 * @function getGasLimit
 *
 * @description Gets gas limit for the transaction
 *
 * @param {object} props - Properties of the web3.eth.estimateGas function
 *
 * @returns Promise that will be resolved with estimate gas for sending of the transaction
 */


exports.signTx = signTx;
exports.getGasLimit = getGasLimit;
exports.getContractGasLimit = getContractGasLimit;

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _ethereumjsTx = require('ethereumjs-tx');

var _ethereumjsTx2 = _interopRequireDefault(_ethereumjsTx);

var _add0x = require('../utils/add0x');

var _add0x2 = _interopRequireDefault(_add0x);

var _config = require('../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @function signTx
 *
 * @description Signs raw transaction data with the specified private key
 *
 * @param {object} rawTx - Transaction data
 * @param {string} privateKey - Private key (64 hex symbols, without '0x' prefix)
 *
 * @returns {string} Serialized string of signed transaction
 */
/**
 * @file Manages helper functions for sending of transactions
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function signTx(rawTx, privateKey) {
  var tx = new _ethereumjsTx2.default(rawTx);
  tx.sign(new Buffer(privateKey, 'hex'));
  var signedTx = tx.serialize().toString('hex');

  return (0, _add0x2.default)(signedTx);
}function getGasLimit(props) {
  return _bluebird2.default.promisify(jWeb3.eth.estimateGas)(props).timeout(_config2.default.promiseTimeout, new Error('Can not get estimate gas'));
}

/**
 * @async
 * @function getContractGasLimit
 *
 * @description Gets gas limit for the contract transaction
 *
 * @param {function} method - Contract method that used to send transaction
 * @param {array} args - Contract method argumets
 *
 * @returns Promise that will be resolved with estimate gas for sending of the contract transaction
 */
function getContractGasLimit(method, args) {
  return _bluebird2.default.promisify(method.estimateGas).apply(undefined, (0, _toConsumableArray3.default)(args)).timeout(_config2.default.promiseTimeout, new Error('Can not get estimate gas for contract method'));
}

function getNonce(address) {
  return _bluebird2.default.promisify(jWeb3.eth.getTransactionCount)(address).timeout(_config2.default.promiseTimeout, new Error('Can not get transaction count'));
}

function getGasPrice() {
  return _bluebird2.default.promisify(jWeb3.eth.getGasPrice)().timeout(_config2.default.promiseTimeout, new Error('Can not get gas price'));
}