'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _joiBrowser = require('joi-browser');

var _joiBrowser2 = _interopRequireDefault(_joiBrowser);

var _validationRules = require('../validationRules');

var _validationRules2 = _interopRequireDefault(_validationRules);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @file Exposes validation schemas for ERC20 interface
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

var totalSupply = _joiBrowser2.default.object().keys(_validationRules.generalContractKeys);

var balanceOf = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  owner: _validationRules2.default.address.required()
}));

var transfer = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  privateKey: _validationRules2.default.privateKey.required(),
  to: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required(),
  gasLimit: _validationRules2.default.gasLimit,
  gasPrice: _validationRules2.default.gasPrice,
  nonce: _validationRules2.default.nonce
}));

var getPastEvents = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  event: _validationRules2.default.event.required(),
  options: _validationRules2.default.eventOptions
}));

var allEvents = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  options: _validationRules2.default.eventOptions,
  callback: _validationRules2.default.callback
}));

var Transfer = allEvents;

var estimateGas = _joiBrowser2.default.object().keys(_validationRules.estimateGasKeys);

exports.default = {
  totalSupply: totalSupply,
  balanceOf: balanceOf,
  transfer: transfer,
  getPastEvents: getPastEvents,
  allEvents: allEvents,
  Transfer: Transfer,
  estimateGas: estimateGas
};