'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _joiBrowser = require('joi-browser');

var _joiBrowser2 = _interopRequireDefault(_joiBrowser);

var _validationRules = require('../validationRules');

var _validationRules2 = _interopRequireDefault(_validationRules);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @file Exposes validation schemas for ERC20Validatable interface
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

var isRegulated = _joiBrowser2.default.object().keys(_validationRules.generalContractKeys);

var isReceivingAllowed = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  account: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required()
}));

var isSpendingAllowed = isReceivingAllowed;

var isTransferAllowed = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  from: _validationRules2.default.address.required(),
  to: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required()
}));

var isApproveAllowed = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  from: _validationRules2.default.address.required(),
  spender: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required()
}));

var isApprovedSpendingAllowed = isApproveAllowed;

var isTransferFromAllowed = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalContractKeys, {
  spender: _validationRules2.default.address.required(),
  from: _validationRules2.default.address.required(),
  to: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required()
}));

var estimateGas = _joiBrowser2.default.object().keys(_validationRules.estimateGasKeys);

exports.default = {
  isRegulated: isRegulated,
  isReceivingAllowed: isReceivingAllowed,
  isSpendingAllowed: isSpendingAllowed,
  isTransferAllowed: isTransferAllowed,
  isApproveAllowed: isApproveAllowed,
  isApprovedSpendingAllowed: isApprovedSpendingAllowed,
  isTransferFromAllowed: isTransferFromAllowed,
  estimateGas: estimateGas
};